Changelog
=========

v1.0.2
----------------
- Update the ReadMe file.

v1.0.1
----------------
- Add query filter for programming languages vocabulary. @b4oshany


v1.0.0
------------------

- Initial release.
  [b4oshany]
- Add vocabularies for programming languages and platform types.
